autoExposureLockingSupported property
autoExposureLockingSupported is the flag to check if auto exposure locking is supported or not.
Implementation
bool autoExposureLockingSupported;
autoExposureLockingSupported is the flag to check if auto exposure locking is supported or not.
bool autoExposureLockingSupported;