autoWhiteBalanceLockingSupported property
autoWhiteBalanceLockingSupported is the flag to check if auto white balance locking is supported or not.
Implementation
bool autoWhiteBalanceLockingSupported;
autoWhiteBalanceLockingSupported is the flag to check if auto white balance locking is supported or not.
bool autoWhiteBalanceLockingSupported;