smoothZoomSupported property
smoothZoomSupported is the flag to check if smooth zoom is supported or not.
Implementation
bool smoothZoomSupported;
smoothZoomSupported is the flag to check if smooth zoom is supported or not.
bool smoothZoomSupported;