videoSnapshotSupported property
videoSnapshotSupported is the flag to check if video snapshot is supported or not.
Implementation
bool videoSnapshotSupported;
videoSnapshotSupported is the flag to check if video snapshot is supported or not.
bool videoSnapshotSupported;