videoStabilizationSupported property
videoStabilizationSupported is the flag to check if video stabilization is supported or not.
Implementation
bool videoStabilizationSupported;
videoStabilizationSupported is the flag to check if video stabilization is supported or not.
bool videoStabilizationSupported;