hiddenSsid property
hiddenSsid The wifi network ssid is hidden oe not.i.e - hidden-true,not hidden-false else null.
Implementation
bool? hiddenSsid;
hiddenSsid The wifi network ssid is hidden oe not.i.e - hidden-true,not hidden-false else null.
bool? hiddenSsid;