ThermalType class
This includes the thermal type name cpu name and the temperature in celcius.
Constructors
- ThermalType({required String name, required String temperature})
- constructor for the class.
- ThermalType.fromJson(String source)
-
returns ThermalType from json string.
factory
-
ThermalType.fromMap(Map<
String, dynamic> map) -
returns ThermalType from map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
The name of cpu core.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature ↔ String
-
The temperature of cpu core in celcius.
getter/setter pair
Methods
-
copyWith(
{String? name, String? temperature}) → ThermalType - copyWith is the function to copy the class.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - returns the json string of thermal type.
-
toMap(
) → Map< String, dynamic> - returns the map of thermal type.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override